@@ -2,11 +2,11 @@ from libcst import BaseExpression, Call, Name
 from libcst import matchers as m
 
 from django_codemod.constants import DJANGO_2_0, DJANGO_3_0
-from django_codemod.visitors.base import BaseSimpleRenameTransformer
+from django_codemod.visitors.base import BaseRenameTransformer
 
 
-class ContextDecoratorTransformer(BaseSimpleRenameTransformer):
-    """Resolve deprecation of ``django.utils.decorators.ContextDecorator``."""
+class ContextDecoratorTransformer(BaseRenameTransformer):
+    """Replace Django's `ContextDecorator` decorator by the `contextlib`'s one."""
 
     deprecated_in = DJANGO_2_0
     removed_in = DJANGO_3_0
@@ -14,8 +14,8 @@ class ContextDecoratorTransformer(BaseSimpleRenameTransformer):
     rename_to = "contextlib.ContextDecorator"
 
 
-class AvailableAttrsTransformer(BaseSimpleRenameTransformer):
-    """Resolve deprecation of ``django.utils.decorators.available_attrs``."""
+class AvailableAttrsTransformer(BaseRenameTransformer):
+    """Replace `django.utils.decorators.available_attrs` by `WRAPPER_ASSIGNMENTS`."""
 
     deprecated_in = DJANGO_2_0
     removed_in = DJANGO_3_0
@@ -23,7 +23,7 @@ class AvailableAttrsTransformer(BaseSimpleRenameTransformer):
     rename_to = "functools.WRAPPER_ASSIGNMENTS"
 
     def leave_Call(self, original_node: Call, updated_node: Call) -> BaseExpression:
-        if self.is_entity_imported and m.matches(
+        if self.is_imported_with_old_name and m.matches(
             updated_node, m.Call(func=m.Name(self.old_name))
         ):
             return Name(self.new_name)
